/*                         C A M E R A V I E W . C P P
 * BRL-CAD
 *
 * Copyright (c) 2018 United States Government as represented by
 * the U.S. Army Research Laboratory.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
/** @file ConsoleView.cpp
 *
 *  BRL-CAD Qt GUI:
 *      implementation projection control view
 */

#include "ConsoleView.h"

#include <QScrollBar>
#include <QTime> 

ConsoleView::ConsoleView
(
    BRLCAD::ConstDatabase& database,
    QWidget*               parent
) : QPlainTextEdit(parent), m_database(database) {

    // connect logger to brlcad 
    document()->setMaximumBlockCount(100);
    setUndoRedoEnabled(false);
    m_userIdentity = "_user_"; 
    ProcessCommandRequest("_message_"); 
    CreateNewline(); 
}

void ConsoleView::CreateNewline(void) 
{
    QTime time          = QTime::currentTime(); 
    QString currentTime = time.toString("hh:mm:ss");
    appendPlainText(m_userIdentity + "@" + currentTime + " $  ");
    m_fixedPosition = textCursor().position(); 
}

void ConsoleView::ProcessCommandRequest(const QString& input)
{ 
    // Output the response 
    if(!input.isEmpty()) 
    {
        appendPlainText(input); 
    }       
}

void ConsoleView::keyPressEvent(QKeyEvent *e)
{
    bool valid; 
    switch (e->key()) 
    {
        case Qt::Key_Left:
        case Qt::Key_Right:
        case Qt::Key_Up:
        case Qt::Key_Down:
            valid = false; 
            break; 
        case Qt::Key_Backspace:
            valid = textCursor().position() > m_fixedPosition; 
            break; 
        case Qt::Key_Return: 
            ProcessCommandRequest(QString::number(m_fixedPosition)); 
            CreateNewline(); 
            valid = false; 
            break; 
        default:
            valid = textCursor().position() >= m_fixedPosition;
            break; 
    }

    if(valid)
        QPlainTextEdit::keyPressEvent(e);   
}

void ConsoleView::mousePressEvent(QMouseEvent *e)
{
    Q_UNUSED(e)
    setFocus();
}

void ConsoleView::mouseDoubleClickEvent(QMouseEvent *e)
{
    Q_UNUSED(e)
}

void ConsoleView::contextMenuEvent(QContextMenuEvent *e)
{
    Q_UNUSED(e)
}

ConsoleView::~ConsoleView(void)
{
}

