/*                           C A M E R A V I E W . H
 * BRL-CAD
 *
 * Copyright (c) 2018 United States Government as represented by
 * the U.S. Army Research Laboratory.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
/** @file ConsoleView.h
 *
 *  BRL-CAD Qt GUI:
 *      declaration projection control view
 */


#ifndef ConsoleView_H
#define ConsoleView_H

#include <QPlainTextEdit>

#include <brlcad/ConstDatabase.h>
#include <brlcad/globals.h>

class ConsoleView : public QPlainTextEdit
{
    Q_OBJECT

public:
    ConsoleView(BRLCAD::ConstDatabase& database,
                QWidget*               parent = 0);
    ~ConsoleView(void); 
protected:
    void keyPressEvent(QKeyEvent *e)            override;
    void mousePressEvent(QMouseEvent *e)        override;
    void mouseDoubleClickEvent(QMouseEvent *e)  override;
    void contextMenuEvent(QContextMenuEvent *e) override;

private:
    BRLCAD::ConstDatabase&  m_database;
    int                     m_fixedPosition; 
    QString                 m_userIdentity; 

    void ProcessCommandRequest(const QString& input); 
    void CreateNewline(void); 
};

#endif // ConsoleView_H